@@ -251,8 +251,8 @@ impl Keypoints {
                             | Keypoint::BezierQuad { to, .. },
                         ) => Keypoint::BezierCubic {
                             to: *to,
-                            control_from: *control_from,
-                            control_to: *control_to,
+                            control_from: *control_to,
+                            control_to: *control_from,
                         },
                     };
 
@@ -282,6 +282,7 @@ pub struct Path {
     pub(crate) path: Vec<Keypoint>,
     pub(crate) closed: bool,
 }
+crate::impl_style!(Path);
 impl Path {
     pub fn new() -> Path {
         Path {
